/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus;

import java.io.File;
import java.io.IOException;

/**
 * <p>
 *  <code>Generator</code> is the portion of Zeus that will convert
 *    a set of constraints, visible through a <code>{@link Binding}</code>,
 *    and output them as generated Java classes (to a 
 *    <code>{@link Result}</code>.
 * </p>
 *
 * @author Brett McLaughlin
 * @version 1.0
 */
public interface Generator {

    /**
     * XXX: Since this is the user interface, there is almost
     *      certainly a set of exceptions that need to exist
     *      and be thrown from the <code>generate()</code> method.
     *      I'll have to add those as they come up.
     */

    /**
     * <p>
     *  This will convert from a set of constraints to Java classes.
     *    It accesses those constraints through the
     *    <code>{@link Binding}</code> interface, which provides
     *    them in a representation-independent format, and then
     *    converts them into Java code, which is output to the
     *    supplied <code>{@link Result}</code>.
     * </p>
     *
     * @param binder <code>Binder</code> with ability to convert from
     *        constraints to Zeus <code>Binding</code>s.
     * @param directory <code>File</code> to output generated classes
     *        to.
     * @throws <code>IOException</code> - when errors in writing to the
     *         supplied <code>Result</code> occur.     
     */
    public void generate(Binding binding, File directory) throws IOException;
}
