/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.binder;

import java.io.IOException;
import java.util.Iterator;
import java.util.List;

// Zeus imports
import org.enhydra.zeus.Binder;
import org.enhydra.zeus.Binding;
import org.enhydra.zeus.Source;

// JDOM imports
import org.jdom.Document;
import org.jdom.Element;

/**
 * <p>
 *  <code>SchemaBinder</code> implements the <code>{@link Binder}</code>
 *    interface and allows generation of Zeus
 *    <code>{@link Binding}</code>s from an XML Schema.
 * </p>
 *
 * @author Brett McLaughlin
 * @version 1.0
 */
public class SchemaBinder extends BaseBinder {

    /**
     * <p>
     *  This constructor takes in a <code>{@link Source}</code>
     *    to read an XML Schema from and allow generation of the 
     *    <code>{@link Binding}</code>s from it.
     * </p>
     *
     * @param source <code>Source</code> to read input from.
     */
    public SchemaBinder(Source source) {
        super(source);
    }

    /**
     * <p>
     *  This is integral portion of the <code>Binder</code>. It
     *    is responsible for returning a Zeus representation of
     *    the set of constraints that this binding represents,
     *    resulting from the supplied XML Schema.
     * </p>
     *
     * @return <code>List</code> - the resultant
     *         <code>Bindings</code> from conversion of
     *         constraints.
     * @throws <code>IOException</code> when errors in reading
     *         input occur.
     */
    public List getBindings() throws IOException {
        Document schema = source.getDocument();
        Element root = schema.getRootElement();
    
        return convertToBindings(root);
    }
    
    /**
     * <p>
     * </p>
     *
     * @param element <code>Element</code> to convert to a Zeus
     *        <code>Binding</code>.
     * @return <code>List</code> - the <code>Binding</code>s from
     *         the supplied <code>Element</code>.
     */
    private List convertToBindings(Element element) {
        // Deal with the elements content
        List mixedContent = element.getMixedContent();
        for (Iterator i = mixedContent.iterator(); i.hasNext(); ) {
            Object content = i.next();
            if (content instanceof Element) {
                Element nextElement = (Element)content;
                System.out.println("Found element: " + nextElement.getName());
            }
            /**
             * We don't (as of now) care about comments, PIs,
             *   entities, or anything else. Everything in an XML
             *   schema is in elements and attributes
             */
        }
        
        // Deal with the element itself
        
        return null;
    }

}
